@@ -1,10 +1,52 @@
-package Role::HasMessage::Errf;
-{
-  $Role::HasMessage::Errf::VERSION = '0.006';
-}
+package Role::HasMessage::Errf 0.007;
 use MooseX::Role::Parameterized;
 # ABSTRACT: a thing with a String::Errf-powered message
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your class...
+#pod
+#pod   package Errfy;
+#pod   use Moose;
+#pod
+#pod   with 'Role::HasMessage::Errf';
+#pod
+#pod   has payload => (
+#pod     is  => 'ro',
+#pod     isa => 'HashRef',
+#pod     required => 1,
+#pod   );
+#pod
+#pod Then...
+#pod
+#pod   my $thing = Errfy->new({
+#pod     message => "%{error_count;error}n encountered at %{when}t",
+#pod     payload => {
+#pod       error_count => 2,
+#pod       when        => time,
+#pod     },
+#pod   });
+#pod
+#pod   # prints: 2 errors encountered at 2010-10-20 19:23:42
+#pod   print $thing->message;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Role::HasMessage::Errf is an implementation of L<Role::HasMessage> that uses
+#pod L<String::Errf> to format C<sprintf>-like message strings.  It adds a
+#pod C<message_fmt> attribute, initialized by the C<message> argument.  The value
+#pod should be a String::Errf format string.
+#pod
+#pod When the provided C<message> method is called, it will fill in the format
+#pod string with the hashref returned by calling the C<payload> method, which I<must
+#pod be implemented by the including class>.
+#pod
+#pod Role::HasMessage::Errf is a L<parameterized role|MooseX::Role::Parameterized>.
+#pod The C<default> parameter lets you set a default format string or callback.  The
+#pod C<lazy> parameter sets whether or not the C<message_fmt> attribute is lazy.
+#pod Setting it lazy will require that a default is provided.
+#pod
+#pod =cut
 
 use String::Errf qw(errf);
 use Try::Tiny;
@@ -64,13 +106,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Role::HasMessage::Errf - a thing with a String::Errf-powered message
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -116,13 +160,23 @@ The C<default> parameter lets you set a default format string or callback.  The
 C<lazy> parameter sets whether or not the C<message_fmt> attribute is lazy.
 Setting it lazy will require that a default is provided.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
